import MarkdownIt from 'markdown-it';
/**
 * This provides the HTML rendering for markdown preview content.
 */
export declare const htmlSectionMarker = "\uF111\uF222\uF333\uF444";
declare const _default: {
    /**
     * Creates a converter and init it with extensions.
     * @returns {Object} A converter.
     */
    createConverter(): MarkdownIt;
    /**
     * Parse markdown sections by passing the 2 first block rules of the markdown-it converter.
     * @param {Object} converter The markdown-it converter.
     * @param {String} text The text to be parsed.
     * @returns {Object} A parsing context to be passed to `convert`.
     */
    parseSections(converter: MarkdownIt, text: string): {
        text: string;
        sections: any[];
        converter: MarkdownIt;
        markdownState: import("markdown-it/lib/rules_core/state_core");
        markdownCoreRules: import("markdown-it/lib/parser_core").RuleCore[];
    };
    /**
     * Convert markdown sections previously parsed with `parseSections`.
     * @param {Object} parsingCtx The parsing context returned by `parseSections`.
     * @param {Object} previousConversionCtx The conversion context returned by a previous call
     * to `convert`, in order to calculate the `htmlSectionDiff` of the returned conversion context.
     * @returns {Object} A conversion context.
     */
    convert(parsingCtx: any, previousConversionCtx: any): {
        text: any;
        sectionList: any;
        htmlSectionList: string[];
        htmlSectionDiff: any;
    };
    /**
     * Helper to highlight arbitrary markdown
     * @param {Object} markdown The markdown content to highlight.
     * @param {Object} converter An optional converter.
     * @param {Object} grammars Optional grammars.
     * @returns {Object} The highlighted markdown in HTML format.
     */
    highlight(markdown: any, converter?: any, grammars?: any): any;
};
export default _default;
//# sourceMappingURL=markdownConversionSvc.d.ts.map